@@ -25,6 +25,8 @@
  */
 
 /* revision history:
+ * 1.3.26a  2004/02/29   hof: ainfo.type changed from long to GapLibAinfoType
+ * 1.3.26a  2004/02/01   hof: added: gap_lib_alloc_ainfo_from_name
  * 1.3.19a  2003/09/06   hof: added gap_lib_searchpath_for_exefile
  * 1.3.16c  2003/07/07   hof: extend ainfo  onion_triggers
  * 1.3.14a  2003/05/27   hof: moved basic gap operations to new module gap_base_ops
@@ -68,6 +70,22 @@
 
 #endif /* !G_OS_WIN32 */
 
+/* GapLibAinfoType enum values are subset of GapStoryVideoType
+ * from the sourcefile gap_story_file.h
+ */
+typedef enum
+{
+     GAP_AINFO_UNUSED_1
+    ,GAP_AINFO_UNUSED_2
+    ,GAP_AINFO_IMAGE
+    ,GAP_AINFO_ANIMIMAGE    
+    ,GAP_AINFO_FRAMES
+    ,GAP_AINFO_MOVIE
+    ,GAP_AINFO_UNUSED_3
+    ,GAP_AINFO_UNKNOWN
+} GapLibAinfoType;
+
+
 typedef struct GapAnimInfo {
    gint32      image_id;
    char        *basename;    /* may include path */
@@ -78,11 +96,15 @@ typedef struct GapAnimInfo {
    GimpRunMode run_mode;
    long         width;       
    long         height;      
-   long         type;    
    long         frame_cnt;   
    long         curr_frame_nr; 
    long         first_frame_nr; 
    long         last_frame_nr;
+   
+   GapLibAinfoType  ainfo_type;
+   gint32           seltrack;    /* input videotrack (used only for GAP_AINFO_MOVIE) */
+   gdouble          delace;      /* deinterlace params (used only for GAP_AINFO_MOVIE) */
+   gdouble          density;     
 } GapAnimInfo;
 
 /* procedures used in other gap*.c files */
@@ -92,6 +114,7 @@ int          gap_lib_file_copy(char *fname, char *fname_copy);
 void         gap_lib_free_ainfo(GapAnimInfo **ainfo);
 char*        gap_lib_alloc_basename(const char *imagename, long *number);
 char*        gap_lib_alloc_extension(const char *imagename);
+GapAnimInfo* gap_lib_alloc_ainfo_from_name(const char *imagename, GimpRunMode run_mode);
 GapAnimInfo* gap_lib_alloc_ainfo(gint32 image_id, GimpRunMode run_mode);
 int          gap_lib_dir_ainfo(GapAnimInfo *ainfo_ptr);
 int          gap_lib_chk_framerange(GapAnimInfo *ainfo_ptr);
